
<div align="center">
    <picture>
    <source srcset="assets/logo/logo_text_black.svg" media="(prefers-color-scheme: light)"/>
    <source srcset="assets/logo/logo_text_white.svg"  media="(prefers-color-scheme: dark)"/>
    <img align="center" src="assets/logo/logo_text_black.svg" alt="Inferno" width="400" style="padding-right: 10px; padding left: 10px;"/>
    </picture>
    <h3>Blazingly-fast Bayesian Deep Learning in PyTorch.</h3>
</div>

## Setup

You can install inferno using `pip`:

<!-- 
```sh
pip install inferno-torch
``` 
-->

```sh
pip install git+https://github.com/inferno-ml/inferno.git
```

## Basic Usage

```python
import inferno
```

